@@ -125,15 +125,15 @@ static void about_cb (AppletWidget *widget, gpointer data)
 	}
 
         about = gnome_about_new ( _("Drive Mount Applet"), VERSION,
-			"(C) 1999",
+			"(C) 2000",
 			authors,
 			_("Released under the GNU general public license.\n"
-			"Mounts and Unmounts drives."
-			"."),
+			  "Mounts and Unmounts drives."),
 			NULL);
 	gtk_signal_connect(GTK_OBJECT(about), "destroy",
 	                   GTK_SIGNAL_FUNC(gtk_widget_destroyed), &about);
 	gtk_widget_show (about);
+
 	return;
 	widget = NULL;
 	data = NULL;
@@ -176,7 +176,7 @@ static gint device_is_in_mountlist(DriveData *dd)
 	gchar buf[201];
 	gint found = FALSE;
 
-	buf[200] = '\0';
+	if (!dd->mount_point) return FALSE;
 
 	fp = popen(command_line, "r");
 
@@ -186,9 +186,9 @@ static gint device_is_in_mountlist(DriveData *dd)
 		return FALSE;
 	}
 
-	while (fgets(buf, 200, fp) != NULL)
+	while (fgets(buf, sizeof(buf), fp) != NULL)
 	{
-		if (strstr(buf, dd->mount_point) != 0) found = TRUE;
+		if (strstr(buf, dd->mount_point) != NULL) found = TRUE;
 	}
 
 	pclose (fp);
@@ -196,24 +196,29 @@ static gint device_is_in_mountlist(DriveData *dd)
 	return found;
 }
 
-static dev_t get_device(gchar *file)
+static gint get_device(gchar *file)
 {
 	struct stat file_info;
-	dev_t t;
+	gint t;
 
 	if (stat (file, &file_info) == -1)
-		t = 0;
+		t = -1;
 	else
-		t = file_info.st_dev;
+		t = (gint)file_info.st_dev;
 
 	return t;
 }
 
 static gint device_is_mounted(DriveData *dd)
 {
+	if (!dd->mount_point || !dd->mount_base) return FALSE;
+
 	if (!dd->autofs_friendly)
 		{
-		if (get_device(dd->mount_base) == get_device(dd->mount_point))
+		gint b, p;
+		b = get_device(dd->mount_base);
+		p = get_device(dd->mount_point);
+		if (b == p || p == -1 || b == -1)
 			return FALSE;
 		else
 			return TRUE;
@@ -359,7 +364,7 @@ static void update_pixmap(DriveData *dd, gint t)
 		}
 
 	tiptext = g_strconcat(dd->mount_point, text, NULL);
-	gtk_tooltips_set_tip (dd->tooltip, dd->applet, tiptext, NULL);
+	applet_widget_set_tooltip(APPLET_WIDGET(dd->applet), tiptext);
 	g_free(tiptext);
 }
 
@@ -451,7 +456,7 @@ static gint mount_cb(GtkWidget *widget, gpointer data)
 
 	str = g_string_new(NULL);
 
-	while (fgets(buf, 200, fp) != NULL)
+	while (fgets(buf, sizeof(buf), fp) != NULL)
 		{
 		gchar *b = buf;
 		g_string_append(str, b);
@@ -486,6 +491,7 @@ static void eject_cb(AppletWidget *applet, gpointer data)
 	gchar mp[200];	/* Mountpoint */
 	FILE *ml;	/* Mountlist */
 
+	if (!dd->mount_point) return;
 
 	/*
 	 * Search the output of mount for dd->mount_point
@@ -497,7 +503,7 @@ static void eject_cb(AppletWidget *applet, gpointer data)
 	
 	if (dd->mounted) {
 		ml = popen("mount", "r");
-		while (fgets(buffer, 200, ml)) {
+		while (fgets(buffer, sizeof(buffer), ml)) {
 			sscanf(buffer, "%s %*s %s", dn, mp);
 			if (!strcmp(mp, dd->mount_point))
 				break;
@@ -505,7 +511,7 @@ static void eject_cb(AppletWidget *applet, gpointer data)
 		pclose (ml);
 	} else {
 		ml = fopen("/etc/fstab", "r");
-		while (fgets(buffer, 200, ml)) {
+		while (fgets(buffer, sizeof(buffer), ml)) {
 			sscanf(buffer, "%s %s", dn, mp);
 			if (!strcmp(mp, dd->mount_point))
 				break;
@@ -602,6 +608,14 @@ static void destroy_drive_widget(GtkWidget *widget, gpointer data)
 	widget = NULL;
 }
 
+static void
+help_cb (GtkWidget *w, gpointer data)
+{
+	GnomeHelpMenuEntry help_entry = { "drivemount_applet",
+					  "index.html" };
+	gnome_help_display(NULL, &help_entry);
+}
+
 static DriveData * create_drive_widget(GtkWidget *applet)
 {
 	DriveData *dd;
@@ -643,8 +657,6 @@ static DriveData * create_drive_widget(GtkWidget *applet)
 				dd);
 	dnd_init(dd);
 
-	dd->tooltip = gtk_tooltips_new();
-
 	/* attach applet signals here */
 
 	gtk_signal_connect(GTK_OBJECT(applet),"change_orient",
@@ -659,17 +671,14 @@ static DriveData * create_drive_widget(GtkWidget *applet)
 	gtk_signal_connect(GTK_OBJECT(applet),"save_session",
 				GTK_SIGNAL_FUNC(applet_save_session),
 				dd);
+
+
 	applet_widget_register_stock_callback(APPLET_WIDGET(applet),
-					      "properties",
-					      GNOME_STOCK_MENU_PROP,
-					      _("Properties..."),
-					      property_show,
+					      "browse",
+					      GNOME_STOCK_MENU_OPEN,
+					      _("Browse..."),
+					      browse_cb,
 					      dd);
-	applet_widget_register_stock_callback(APPLET_WIDGET(applet),
-					      "about",
-					      GNOME_STOCK_MENU_ABOUT,
-					      _("About..."),
-					      about_cb, NULL);
 
 	/* add "eject" entry if eject program is found in PATH */
 	tmp_path = gnome_is_program_in_path("eject");
@@ -684,11 +693,21 @@ static DriveData * create_drive_widget(GtkWidget *applet)
 		}
 
 	applet_widget_register_stock_callback(APPLET_WIDGET(applet),
-					      "browse",
-					      GNOME_STOCK_MENU_OPEN,
-					      _("Browse..."),
-					      browse_cb,
+					      "properties",
+					      GNOME_STOCK_MENU_PROP,
+					      _("Properties..."),
+					      property_show,
 					      dd);
+	applet_widget_register_stock_callback(APPLET_WIDGET(applet),
+					      "help",
+					      GNOME_STOCK_PIXMAP_HELP,
+					      _("Help"),
+					      help_cb, NULL);
+	applet_widget_register_stock_callback(APPLET_WIDGET(applet),
+					      "about",
+					      GNOME_STOCK_MENU_ABOUT,
+					      _("About..."),
+					      about_cb, NULL);
 
 	redraw_pixmap(dd);
 	gtk_widget_show(applet);
