@@ -154,7 +154,7 @@ static void property_apply_cb( GtkWidget *widget, void *data, DriveData *dd)
 	dd->autofs_friendly = dd->prop_autofs_friendly;
 	new_file = gtk_entry_get_text(GTK_ENTRY(dd->mount_point_entry));
 	if (dd->mount_point) g_free(dd->mount_point);
-	dd->mount_point = strdup(new_file);
+	dd->mount_point = g_strdup(new_file);
         dd->interval = dd->prop_interval;
 	if (dd->device_pixmap != dd->prop_device_pixmap)
 		{
@@ -183,6 +183,14 @@ static gint property_destroy_cb( GtkWidget *w, DriveData *dd)
 	w = NULL;
 }
 
+static void
+phelp_cb (GtkWidget *w, gint tab, gpointer data)
+{
+	GnomeHelpMenuEntry help_entry = { "drivemount_applet",
+					  "index.html#drivemountapplet-prefs" };
+	gnome_help_display(NULL, &help_entry);
+}
+
 void property_show(AppletWidget *applet, gpointer data)
 {
         static GnomeHelpMenuEntry help_entry = { NULL, "properties" };
@@ -211,8 +219,8 @@ void property_show(AppletWidget *applet, gpointer data)
 	dd->prop_scale_applet = dd->scale_applet;
 
 	dd->propwindow = gnome_property_box_new();
-	gtk_window_set_title(GTK_WINDOW(&GNOME_PROPERTY_BOX(dd->propwindow)->dialog.window),
-		_("Drive Mount Settings"));
+	gtk_window_set_title(GTK_WINDOW(GNOME_PROPERTY_BOX(dd->propwindow)),
+		_("Drive Mount Applet Properties"));
 
 	frame = gtk_frame_new(NULL);
 	gtk_container_set_border_width(GTK_CONTAINER(frame), GNOME_PAD_SMALL);
@@ -352,8 +360,7 @@ void property_show(AppletWidget *applet, gpointer data)
 			    GTK_SIGNAL_FUNC(property_destroy_cb), dd );
 
 	gtk_signal_connect( GTK_OBJECT(dd->propwindow), "help",
-			    GTK_SIGNAL_FUNC(gnome_help_pbox_display),
-			    &help_entry );
+			    GTK_SIGNAL_FUNC(phelp_cb), NULL);
 
 	gtk_widget_show_all(dd->propwindow);
 	return;
