@@ -1,4 +1,4 @@
-/* $Id: gweather-applet.c,v 1.15 2000/02/29 21:13:14 jberkman Exp $ */
+/* $Id: gweather-applet.c,v 1.18 2000/03/16 16:50:11 jberkman Exp $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -70,7 +70,7 @@ static void place_widgets (void)
     size = 48;
 #endif /* HAVE_PANEL_PIXEL_SIZE */
 
-    if ((gweather_orient == ORIENT_LEFT) || (gweather_orient == ORIENT_RIGHT)) {
+    if (((gweather_orient == ORIENT_LEFT) || (gweather_orient == ORIENT_RIGHT)) ^ (size < 25)) {
         gint sep = MAX(0, (size - pix_requisition.width - lbl_requisition.width) / 3);
         gint lbl_x = sep + pix_requisition.width + sep;
         if (lbl_x + lbl_requisition.width > size) {
@@ -78,11 +78,11 @@ static void place_widgets (void)
             sep = MAX(0, (size - pix_requisition.width) / 2);
         }
 
-        gtk_widget_set_usize(frame, size, 26);
-        gtk_fixed_move(GTK_FIXED(fixed), pixmap, sep, 5);
-        gtk_fixed_move(GTK_FIXED(fixed), label, lbl_x, 4);
+        gtk_widget_set_usize(frame, MAX (size, 48), 24);
+        gtk_fixed_move(GTK_FIXED(fixed), pixmap, sep, 2);
+        gtk_fixed_move(GTK_FIXED(fixed), label, lbl_x, 2);
     } else {
-        gint panel_width = MAX(lbl_requisition.width, 24) + 2;
+        gint panel_width = MAX(lbl_requisition.width, 22);
         gint sep = MAX(0, (size - pix_requisition.height - lbl_requisition.height) / 3);
         gint lbl_y = sep + pix_requisition.height + sep;
         if (lbl_y + lbl_requisition.height > size) {
@@ -90,7 +90,7 @@ static void place_widgets (void)
             sep = MAX(0, (size - pix_requisition.height) / 2);
         }
 
-        gtk_widget_set_usize(frame, panel_width, size);
+        gtk_widget_set_usize(frame, 24, size);
         gtk_fixed_move(GTK_FIXED(fixed), pixmap, (panel_width - pix_requisition.width) / 2 - 1, sep);
         gtk_fixed_move(GTK_FIXED(fixed), label, (panel_width - lbl_requisition.width) / 2, lbl_y);
     }
@@ -182,21 +182,27 @@ void gweather_applet_create (int argc, char *argv[])
     gtk_widget_set_events(gweather_applet, gtk_widget_get_events(gweather_applet) | \
                           GDK_BUTTON_PRESS_MASK);
 
-    applet_widget_register_stock_callback (APPLET_WIDGET(gweather_applet), "preferences",
-                                           GNOME_STOCK_MENU_PREF, _("Properties..."),
-                                           pref_cb, NULL);
+    applet_widget_register_stock_callback (APPLET_WIDGET(gweather_applet),
+					   "about",
+                                           GNOME_STOCK_MENU_ABOUT,
+					   _("About..."),
+                                           about_cb, NULL);
     applet_widget_register_stock_callback (APPLET_WIDGET(gweather_applet), 
 					   "help",
 					   GNOME_STOCK_PIXMAP_HELP,
 					   _("Help"),
 					   help_cb, NULL);
-
-    applet_widget_register_stock_callback (APPLET_WIDGET(gweather_applet), "about",
-                                           GNOME_STOCK_MENU_ABOUT, _("About..."),
-                                           about_cb, NULL);
-    applet_widget_register_stock_callback (APPLET_WIDGET(gweather_applet), "update",
-					   GNOME_STOCK_MENU_REFRESH, _("Update"),
+    applet_widget_register_stock_callback (APPLET_WIDGET(gweather_applet),
+					   "update",
+					   GNOME_STOCK_MENU_REFRESH,
+					   _("Update"),
 					   update_cb, NULL);
+    applet_widget_register_stock_callback (APPLET_WIDGET(gweather_applet),
+					   "preferences",
+                                           GNOME_STOCK_MENU_PREF,
+					   _("Properties..."),
+                                           pref_cb, NULL);
+
 
 #ifdef HAVE_SAVE_SESSION_SIGNAL
     gtk_signal_connect (GTK_OBJECT(gweather_applet), "save_session",
@@ -298,6 +304,7 @@ static gint timeout_cb (gpointer data)
 
 static void update_finish (WeatherInfo *info)
 {
+    char *s;
     /* Save weather info */
     gweather_info = info;
 
@@ -315,7 +322,9 @@ static void update_finish (WeatherInfo *info)
     place_widgets();
 
     /* Update tooltip */
-    gtk_tooltips_set_tip(tooltips, gweather_applet, weather_info_get_weather_summary(gweather_info), NULL);
+    s = weather_info_get_weather_summary(gweather_info);
+    gtk_tooltips_set_tip(tooltips, gweather_applet, s, NULL);
+    g_free (s);
 
     /* Update timer */
     if (timeout_tag > 0)
