@@ -74,7 +74,8 @@ make_memload_applet (const gchar *goad_id)
     g = load_graph_new (APPLET_WIDGET (applet), 4, N_("Memory Load"),
 			&multiload_properties.memload, prop_data,
 			multiload_properties.memload.adj_data[0],
-			multiload_properties.memload.adj_data[1], GetMemory);
+			multiload_properties.memload.adj_data[1], GetMemory,
+			"memload-applet.html#MEMLOAD-PROPERTIES");
 
     applet_widget_add (APPLET_WIDGET(applet), g->main_widget);
     gtk_widget_show (applet);
@@ -101,6 +102,13 @@ make_memload_applet (const gchar *goad_id)
 					   _("Run gtop..."),
 					   start_gtop_cb, NULL);
 
+    applet_widget_register_stock_callback (APPLET_WIDGET(applet),
+					   "help",
+					   GNOME_STOCK_PIXMAP_HELP,
+					   _("Help"),
+					   multiload_help_cb,
+					   "memload-applet.html");
+
     applet_widget_register_stock_callback (APPLET_WIDGET(applet),
 					   "about",
 					   GNOME_STOCK_MENU_ABOUT,
