@@ -125,10 +125,18 @@ reset_cb (AppletWidget *widget, gpointer data)
 static void
 about_cb (AppletWidget *widget, gpointer data)
 {
-   GtkWidget *about;
+   static GtkWidget *about = NULL;
 
    const gchar *authors[] = {
    	"Fabrice Bellet <Fabrice.Bellet@creatis.insa-lyon.fr>",NULL};
+
+   if (about != NULL)
+   {
+	gdk_window_show(about->window);
+	gdk_window_raise(about->window);
+	return;
+   }
+
    about=gnome_about_new (_("Odometer"),
    	ODO_VERSION,
    	_("(C) 1999 The Free Software Foundation"),
@@ -136,6 +144,8 @@ about_cb (AppletWidget *widget, gpointer data)
    	_("a GNOME applet that tracks and measures the movements "
    	"of your mouse pointer across the desktop."),
    	NULL);
+   gtk_signal_connect( GTK_OBJECT(about), "destroy",
+		       GTK_SIGNAL_FUNC(gtk_widget_destroyed), &about );
    gtk_widget_show (about);
    return;
    widget = NULL;
@@ -603,6 +613,13 @@ init_applet (OdoApplet *oa)
    oa->theme_entry=NULL;
 }
 
+static void
+help_cb (AppletWidget *applet, gpointer data)
+{
+    GnomeHelpMenuEntry help_entry = { "odometer_applet", "index.html"};
+    gnome_help_display(NULL, &help_entry);
+}
+
 int
 main (int argc, char *argv[])
 {
@@ -639,6 +656,9 @@ main (int argc, char *argv[])
    applet_widget_register_stock_callback (APPLET_WIDGET (oa->applet),
    	"properties",GNOME_STOCK_MENU_PROP,
    	_("Properties..."),GTK_SIGNAL_FUNC(properties_cb),oa);
+   applet_widget_register_stock_callback (APPLET_WIDGET (oa->applet),
+	"help", GNOME_STOCK_PIXMAP_HELP,
+	_("Help"), help_cb, NULL);					  
    applet_widget_register_stock_callback (APPLET_WIDGET (oa->applet),
    	"about",GNOME_STOCK_MENU_ABOUT,
    	_("About..."),GTK_SIGNAL_FUNC(about_cb),oa);
