@@ -57,7 +57,7 @@ cb_about (AppletWidget * widget, gpointer data)
 		      GTK_SIGNAL_FUNC(gtk_widget_destroyed), &about );
 
   my_url = gnome_href_new ("http://www.tomgilbert.freeserve.co.uk",
-			   "Visit the author's Website");
+			   _("Visit the author's Website"));
   gtk_widget_show (my_url);
   gtk_box_pack_start (GTK_BOX ((GNOME_DIALOG (about))->vbox), my_url, FALSE,
 		      FALSE, 0);
@@ -1004,7 +1004,7 @@ main (int argc, char *argv[])
 					 (AppletCallbackFunc) cb_about, NULL);
   applet_widget_register_stock_callback (APPLET_WIDGET (applet),
 					 "help",
-					 GNOME_STOCK_MENU_ABOUT,
+					 GNOME_STOCK_PIXMAP_HELP,
 					 _ ("Help"),
 					 (AppletCallbackFunc) showHelp, NULL);
 
